import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
import { toEntryPatterns } from '../playwright/index.js';
export const NAME = 'Playwright for components';
export const ENABLERS = [/^@playwright\/experimental-ct-/];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['playwright-ct.config.{js,ts}', 'playwright/index.{js,ts,jsx,tsx}'];
export const ENTRY_FILE_PATTERNS = ['**/*.@(spec|test).?(c|m)[jt]s?(x)'];
const findPlaywrightCTDependencies = async (configFilePath, { cwd }) => {
    const config = await load(configFilePath);
    const entryPatterns = toEntryPatterns(config.testMatch, cwd, configFilePath, config);
    if (entryPatterns.length > 0)
        return entryPatterns;
    return toEntryPatterns(ENTRY_FILE_PATTERNS, cwd, configFilePath, config);
};
export const findDependencies = timerify(findPlaywrightCTDependencies);
